@@ -14,6 +14,7 @@
 
 import os.path
 
+from giza.tools.strings import hyph_concat
 from giza.tools.files import copy_if_needed, create_link, tarball
 
 def html_tarball(builder, conf):
@@ -25,7 +26,7 @@ def html_tarball(builder, conf):
 
     basename = os.path.join(conf.paths.projectroot,
                             conf.paths.public_site_output,
-                            conf.project.name + '-' + conf.git.branches.current)
+                            hyph_concat(conf.project.name, ) + '-' + conf.git.branches.current)
 
     tarball_name = basename + '.tar.gz'
 
@@ -46,6 +47,37 @@ def html_tarball(builder, conf):
     create_link(input_fn=os.path.basename(tarball_name),
                  output_fn=link_name)
 
+def slides_tarball(builder, conf):
+    copy_if_needed(os.path.join(conf.paths.projectroot,
+                                conf.paths.includes, 'hash.rst'),
+                   os.path.join(conf.paths.projectroot,
+                                conf.paths.branch_output,
+                                builder, 'release.txt'))
+
+    basename = os.path.join(conf.paths.projectroot,
+                            conf.paths.public_site_output,
+                            hyph_concat(conf.project.name,
+                                        conf.git.branches.current,
+                                        builder))
+
+    tarball_fn = basename + '.tar.gz'
+
+    tarball(name=tarball_fn,
+            path=builder,
+            cdir=os.path.join(conf.paths.projectroot,
+                              conf.paths.branch_output),
+            newp=os.path.basename(basename))
+
+    link_name = os.path.join(conf.paths.projectroot,
+                             conf.paths.public_site_output,
+                             hyph_concat(conf.project.name, 'slides') + '.tar.gz')
+
+    if os.path.exists(link_name):
+        os.remove(link_name)
+
+    create_link(input_fn=os.path.basename(tarball_fn),
+                 output_fn=link_name)
+
 def man_tarball(builder, conf):
     basename = os.path.join(conf.paths.projectroot,
                             conf.paths.public_site_output,
